var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { TransitionMotion, spring } from 'react-motion';
import { motionPropTypes } from '../../../props';
import { getInheritedColorGenerator } from '../../../lib/colorUtils';
import { positionFromAngle } from '../../../lib/arcUtils';

var RadarMarkers = function (_Component) {
    _inherits(RadarMarkers, _Component);

    function RadarMarkers() {
        _classCallCheck(this, RadarMarkers);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    RadarMarkers.prototype.render = function render() {
        var _props = this.props,
            data = _props.data,
            radiusScale = _props.radiusScale,
            angleStep = _props.angleStep,
            size = _props.size,
            color = _props.color,
            borderWidth = _props.borderWidth,
            borderColor = _props.borderColor,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        var fillColor = getInheritedColorGenerator(color);
        var strokeColor = getInheritedColorGenerator(borderColor);

        var points = data.reduce(function (acc, serie) {
            var id = serie.id,
                serieData = serie.data;


            return [].concat(acc, serieData.map(function (d, i) {
                return _extends({
                    key: id + '.' + i,
                    fill: fillColor(serie),
                    stroke: strokeColor(serie)
                }, positionFromAngle(angleStep * i - Math.PI / 2, radiusScale(d)));
            }));
        }, []);

        var circles = void 0;
        if (animate === true) {
            var springConfig = {
                motionDamping: motionDamping,
                motionStiffness: motionStiffness
            };

            circles = React.createElement(
                TransitionMotion,
                {
                    styles: points.map(function (point) {
                        return {
                            key: point.key,
                            data: {
                                fill: point.fill,
                                stroke: point.stroke
                            },
                            style: {
                                x: spring(point.x, springConfig),
                                y: spring(point.y, springConfig),
                                size: spring(size, springConfig)
                            }
                        };
                    })
                },
                function (interpolatedStyles) {
                    return React.createElement(
                        'g',
                        null,
                        interpolatedStyles.map(function (_ref) {
                            var key = _ref.key,
                                style = _ref.style,
                                data = _ref.data;
                            return React.createElement('circle', {
                                key: key,
                                cx: style.x,
                                cy: style.y,
                                r: style.size / 2,
                                fill: data.fill,
                                stroke: data.stroke,
                                strokeWidth: borderWidth
                            });
                        })
                    );
                }
            );
        } else {
            circles = points.map(function (point) {
                return React.createElement('circle', {
                    key: point.key,
                    cx: point.x,
                    cy: point.y,
                    r: size / 2,
                    fill: point.fill,
                    stroke: point.stroke,
                    strokeWidth: borderWidth
                });
            });
        }

        return React.createElement(
            'g',
            null,
            circles
        );
    };

    return RadarMarkers;
}(Component);

RadarMarkers.propTypes = _extends({
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        color: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.number).isRequired
    })),
    radiusScale: PropTypes.func.isRequired,
    angleStep: PropTypes.number.isRequired,
    size: PropTypes.number.isRequired,
    color: PropTypes.oneOfType([PropTypes.string, PropTypes.func]).isRequired,
    borderWidth: PropTypes.number.isRequired,
    borderColor: PropTypes.oneOfType([PropTypes.string, PropTypes.func]).isRequired
}, motionPropTypes);
RadarMarkers.defaultProps = {
    size: 6,
    color: 'inherit',
    borderWidth: 0,
    borderColor: 'inherit',

    animate: true,
    motionStiffness: 90,
    motionDamping: 15
};
export default RadarMarkers;